package com.ruoyi.rocketmq.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.rocketmq.mapper.RmTemplateSwitchMapper;
import com.ruoyi.rocketmq.domain.RmTemplateSwitch;
import com.ruoyi.rocketmq.service.IRmTemplateSwitchService;

/**
 * 交换机监控模板Service业务层处理
 * 
 * @author gyt
 * @date 2025-09-09
 */
@Service
public class RmTemplateSwitchServiceImpl implements IRmTemplateSwitchService 
{
    @Autowired
    private RmTemplateSwitchMapper rmTemplateSwitchMapper;

    /**
     * 查询交换机监控模板
     * 
     * @param id 交换机监控模板主键
     * @return 交换机监控模板
     */
    @Override
    public RmTemplateSwitch selectRmTemplateSwitchById(Long id)
    {
        return rmTemplateSwitchMapper.selectRmTemplateSwitchById(id);
    }

    /**
     * 查询交换机监控模板列表
     * 
     * @param rmTemplateSwitch 交换机监控模板
     * @return 交换机监控模板
     */
    @Override
    public List<RmTemplateSwitch> selectRmTemplateSwitchList(RmTemplateSwitch rmTemplateSwitch)
    {
        return rmTemplateSwitchMapper.selectRmTemplateSwitchList(rmTemplateSwitch);
    }

    /**
     * 新增交换机监控模板
     * 
     * @param rmTemplateSwitch 交换机监控模板
     * @return 结果
     */
    @Override
    public int insertRmTemplateSwitch(RmTemplateSwitch rmTemplateSwitch)
    {
        rmTemplateSwitch.setCreateTime(DateUtils.getNowDate());
        return rmTemplateSwitchMapper.insertRmTemplateSwitch(rmTemplateSwitch);
    }

    /**
     * 修改交换机监控模板
     * 
     * @param rmTemplateSwitch 交换机监控模板
     * @return 结果
     */
    @Override
    public int updateRmTemplateSwitch(RmTemplateSwitch rmTemplateSwitch)
    {
        rmTemplateSwitch.setUpdateTime(DateUtils.getNowDate());
        return rmTemplateSwitchMapper.updateRmTemplateSwitch(rmTemplateSwitch);
    }

    /**
     * 批量删除交换机监控模板
     * 
     * @param ids 需要删除的交换机监控模板主键
     * @return 结果
     */
    @Override
    public int deleteRmTemplateSwitchByIds(Long[] ids)
    {
        return rmTemplateSwitchMapper.deleteRmTemplateSwitchByIds(ids);
    }

    /**
     * 删除交换机监控模板信息
     * 
     * @param id 交换机监控模板主键
     * @return 结果
     */
    @Override
    public int deleteRmTemplateSwitchById(Long id)
    {
        return rmTemplateSwitchMapper.deleteRmTemplateSwitchById(id);
    }
}
