package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.RmTemplateSwitch;
import com.ruoyi.rocketmq.service.IRmTemplateSwitchService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 交换机监控模板Controller
 * 
 * @author gyt
 * @date 2025-09-09
 */
@RestController
@RequestMapping("/switch")
public class RmTemplateSwitchController extends BaseController
{
    @Autowired
    private IRmTemplateSwitchService rmTemplateSwitchService;

    /**
     * 查询交换机监控模板列表
     */
    @RequiresPermissions("rocketmq:switch:list")
    @GetMapping("/list")
    public TableDataInfo list(RmTemplateSwitch rmTemplateSwitch)
    {
        startPage();
        List<RmTemplateSwitch> list = rmTemplateSwitchService.selectRmTemplateSwitchList(rmTemplateSwitch);
        return getDataTable(list);
    }

    /**
     * 导出交换机监控模板列表
     */
    @RequiresPermissions("rocketmq:switch:export")
    @Log(title = "交换机监控模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RmTemplateSwitch rmTemplateSwitch)
    {
        List<RmTemplateSwitch> list = rmTemplateSwitchService.selectRmTemplateSwitchList(rmTemplateSwitch);
        ExcelUtil<RmTemplateSwitch> util = new ExcelUtil<RmTemplateSwitch>(RmTemplateSwitch.class);
        util.exportExcel(response, list, "交换机监控模板数据");
    }

    /**
     * 获取交换机监控模板详细信息
     */
    @RequiresPermissions("rocketmq:switch:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(rmTemplateSwitchService.selectRmTemplateSwitchById(id));
    }

    /**
     * 新增交换机监控模板
     */
    @RequiresPermissions("rocketmq:switch:add")
    @Log(title = "交换机监控模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RmTemplateSwitch rmTemplateSwitch)
    {
        return toAjax(rmTemplateSwitchService.insertRmTemplateSwitch(rmTemplateSwitch));
    }

    /**
     * 修改交换机监控模板
     */
    @RequiresPermissions("rocketmq:switch:edit")
    @Log(title = "交换机监控模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RmTemplateSwitch rmTemplateSwitch)
    {
        return toAjax(rmTemplateSwitchService.updateRmTemplateSwitch(rmTemplateSwitch));
    }

    /**
     * 删除交换机监控模板
     */
    @RequiresPermissions("rocketmq:switch:remove")
    @Log(title = "交换机监控模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(rmTemplateSwitchService.deleteRmTemplateSwitchByIds(ids));
    }
}
